@@ -5,7 +5,7 @@
 #include <KArchive/kcompressiondevice.h>
 #include <KArchive/kfilterdev.h>
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
 #include <KArchive/k7zip.h>
 #endif
 
