@@ -30,6 +30,7 @@
 #include "controllers/filepreviewer.h"
 #include "controllers/dirinfo.h"
 #include "controllers/folderconfig.h"
+#include "controllers/fileproperties.h"
 
 #include "index.h"
 
@@ -63,7 +64,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     KLocalizedString::setApplicationDomain("index");
 
     KAboutData about(QStringLiteral("index"), i18n("Index"), INDEX_VERSION_STRING, i18n("Browse, organize and preview your files."),
-                     KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+                     KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
 
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.addAuthor(i18n("Gabriel Dominguez"), i18n("Developer"), QStringLiteral("gabriel@gabrieldominguez.es"));
@@ -76,9 +77,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
+    parser.setApplicationDescription(about.shortDescription());
     parser.process(app);
-
-    about.setupCommandLine(&parser);
     about.processCommandLine(&parser);
 
     const QStringList args = parser.positionalArguments();
@@ -109,7 +109,9 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<RecentFilesModel>(INDEX_URI, 1, 0, "RecentFiles");
     qmlRegisterType<DirInfo>(INDEX_URI, 1, 0, "DirInfo");
     qmlRegisterType<PathList>(INDEX_URI, 1, 0, "PathList");
-//    qmlRegisterType<FolderConfig>(INDEX_URI, 1, 0, "FolderConfig");
+    //    qmlRegisterType<FolderConfig>(INDEX_URI, 1, 0, "FolderConfig");
+    qmlRegisterType<FileProperties>(INDEX_URI, 1, 0, "FileProperties");
+    qmlRegisterType<Permission>(INDEX_URI, 1, 0, "Permission");
 
     engine.load(url);
 
